@@ -184,7 +184,7 @@ class App(urwid_directory_chooser.App):
 		lsblk.udisksctl.set_logger(self)
 		self.frameview = urwid.Frame(None)
 		self.screen = self.create_screen()
-		self.loop = urwid.MainLoop(self.frameview, screen=self.screen, input_filter=self.input_filter, unhandled_input=self.unhandled_input, handle_mouse=self.handle_mouse)
+		self.loop = urwid.MainLoop(self.frameview, screen=self.screen, input_filter=self.input_filter, handle_mouse=self.handle_mouse)
 		self._last_view: typing.Optional[LastView] = None
 		urwid_colors.ColorStr.set_logger(self)
 		urwid_colors.ColorStr.set_register_color(self.register_color)
@@ -362,9 +362,12 @@ class App(urwid_directory_chooser.App):
 		return os.path.isabs(name) or name.split(os.path.sep)[0] in (os.path.curdir, os.path.pardir)
 
 	def ask_to_create_backup_plan(self, name: str, fn: str) -> None:
-		dialog = urwid_dialog.YesNoDialog(self, f'Backup plan {name!r} does not exist. Do you want to create it?', yes=lambda: self.ask_for_backup_plan_data(name, fn), no=self.quit)
-		dialog.set_key_handler(self.handle_key)
-		self.open_view(dialog)
+		self.open_view(urwid_dialog.YesNoDialog(self,
+			f'Backup plan {name!r} does not exist. Do you want to create it?',
+			yes = lambda: self.ask_for_backup_plan_data(name, fn),
+			no = self.quit,
+			key_handler = self.handle_key,
+		))
 
 	def ask_for_backup_plan_data(self, name: str, fn: str) -> None:
 		self.open_view(BackupPlanWidget(self, name, fn, create=self.create_backup_plan, cancel=self.quit))
@@ -386,6 +389,7 @@ class App(urwid_directory_chooser.App):
 			'I have created {fn}.\nDo you want to edit it (e.g. to change default directions)?'.format(fn=fn),
 			yes = lambda: self.edit_backup_plan_and_start(fn),
 			no = self.init_model,
+			key_handler = self.handle_key,
 		))
 
 	def edit_backup_plan_and_start(self, fn: str) -> None:
@@ -512,18 +516,6 @@ class App(urwid_directory_chooser.App):
 
 	# ------- actions -------
 
-	def unhandled_input(self, key: URWID_TYPE_KEY) -> bool:
-		cmd = urwid.command_map[key]
-		if cmd == QUIT:
-			self.quit()
-		elif cmd == QUIT_ASK:
-			self.ask_to_quit()
-		elif cmd == QUIT_ASK_IF_LONG:
-			self.ask_to_quit_if_long_startup()
-		else:
-			return False
-		return True
-
 	def ask_to_quit_if_long_startup(self) -> None:
 		now = time.time()
 		t0 = getattr(self, 't0', now)
@@ -543,7 +535,8 @@ class App(urwid_directory_chooser.App):
 			self,
 			'Do you want to close this program?'.format(),
 			yes = self.quit,
-			no = lambda: self.open_view(last_view)
+			no = lambda: self.open_view(last_view),
+			key_handler = self.handle_key,
 		))
 		self.is_ask_to_quit_dialog_open = True
 
@@ -620,6 +613,7 @@ class App(urwid_directory_chooser.App):
 	def close_help(self) -> None:
 		assert self._last_view is not None
 		self.open_view(self._last_view)
+		self._last_view = None
 
 
 	# ------- main -------
@@ -1200,8 +1194,8 @@ class PathsGroup(urwid.WidgetWrap):
 		return self._w.base_widget
 
 	def __init__(self, app: App, master: 'BackupPlanWidget') -> None:
-		self.path_src = urwid_directory_chooser.PathEdit(app, 'src: ', '')
-		self.path_dst = urwid_directory_chooser.PathEdit(app, 'dst: ', '')
+		self.path_src = urwid_directory_chooser.PathEdit(app, 'src: ', '', key_handler=app.handle_key)
+		self.path_dst = urwid_directory_chooser.PathEdit(app, 'dst: ', '', key_handler=app.handle_key)
 		self.btn_add = urwid_dialog.ColorButton('+', master.add_path_group)
 		self.btn_del = urwid_dialog.ColorButton('-', master.del_path_group)
 
@@ -1296,6 +1290,8 @@ class BackupPlanWidget(urwid.WidgetWrap, View):
 			self.was_edit_path_focused = not self.was_edit_path_focused
 			if not any(w.has_opened_directory_chooser() for w, options in self.pile.contents if isinstance(w, PathsGroup)):
 				self.on_path_edit_focus_change(self.was_edit_path_focused)
+		if out:
+			return self.app.handle_key(self._command_map, size, key)
 		return typing.cast(typing.Optional[URWID_TYPE_KEY], out)
 
 	def is_edit_path_focused(self) -> bool:
