@@ -232,12 +232,18 @@ class YesNoDialog(urwid.WidgetWrap, urwid_multi_key_support.MultiKeySupport, Vie
 		urwid_multi_key_support.HelpItem('prev selectable', 'focus previous'),
 	])
 
-	def __init__(self, pressed_keys_opener: urwid_multi_key_support.OverlayPressedKeysOpener, question: str, yes: typing.Callable[[], None], no: typing.Callable[[], None]) -> None:
+	def __init__(self,
+		pressed_keys_opener: urwid_multi_key_support.OverlayPressedKeysOpener,
+		question: str,
+		yes: typing.Callable[[], None],
+		no: typing.Callable[[], None],
+		key_handler: typing.Optional[typing.Callable[[urwid_multi_key_support.SubCommandMap, URWID_TYPE_SIZE, URWID_TYPE_KEY], typing.Optional[URWID_TYPE_KEY]]],
+	) -> None:
 		self.pressed_keys_opener = pressed_keys_opener
 		self.text = urwid.Text(question.strip() + '\n')
 		self.btn_yes = ColorButton(self.BTN_YES, lambda btn: yes())
 		self.btn_no = ColorButton(self.BTN_NO, lambda btn: no())
-		self.key_handler: typing.Optional[typing.Callable[[urwid_multi_key_support.SubCommandMap, URWID_TYPE_SIZE, URWID_TYPE_KEY], typing.Optional[URWID_TYPE_KEY]]] = None
+		self.key_handler = key_handler
 
 		text_width = self.text.pack((self.MAX_TEXT_WIDTH,))[0]
 		widget = ButtonsFrame(self.btn_yes, self.btn_no, cycle_focus=True)
@@ -247,9 +253,6 @@ class YesNoDialog(urwid.WidgetWrap, urwid_multi_key_support.MultiKeySupport, Vie
 		super().__init__(widget)
 		self.init_multi_key_support(pressed_keys_opener)
 
-	def set_key_handler(self, callback: typing.Callable[[urwid_multi_key_support.SubCommandMap, URWID_TYPE_SIZE, URWID_TYPE_KEY], typing.Optional[URWID_TYPE_KEY]]) -> None:
-		self.key_handler = callback
-
 	def keypress(self, size: URWID_TYPE_SIZE, key: URWID_TYPE_KEY) -> typing.Optional[URWID_TYPE_KEY]:
 		if self.waiting_for_next_key(key):
 			return None
