@@ -159,11 +159,19 @@ class DirectoryChooser(urwid.WidgetWrap, urwid_multi_key_support.MultiKeySupport
 
 	# ------- init -------
 
-	def __init__(self, app: App, select: typing.Callable[[str], None], cancel: typing.Callable[[], None], start_path: str = '', show_hidden: bool = False) -> None:
+	def __init__(self,
+		app: App,
+		select: typing.Callable[[str], None],
+		cancel: typing.Callable[[], None],
+		start_path: str = '',
+		show_hidden: bool = False,
+		key_handler: typing.Optional[typing.Callable[[urwid_multi_key_support.SubCommandMap, URWID_TYPE_SIZE, URWID_TYPE_KEY], typing.Optional[URWID_TYPE_KEY]]] = None,
+	) -> None:
 		self.app = app
 		self.show_hidden = show_hidden
 		self.name_of_last_focused_directory: typing.Dict[str, str] = {}
 		self.cancel = cancel
+		self.key_handler = key_handler
 
 		self.text_path = ExtendedEdit('')
 		self.listwalker = urwid.SimpleListWalker([])
@@ -366,9 +374,12 @@ class DirectoryChooser(urwid.WidgetWrap, urwid_multi_key_support.MultiKeySupport
 			self.listbox.set_focus(0)
 		elif cmd == CURSOR_MAX_DOWN:
 			self.listbox.set_focus(len(self.listbox.body)-1)
+		elif self.key_handler and not self.key_handler(self._command_map, size, key):
+			pass
 		else:
 			self.reset_command_map()
 			return key
+
 		self.reset_command_map()
 		return None
 
@@ -383,6 +394,8 @@ class DirectoryChooser(urwid.WidgetWrap, urwid_multi_key_support.MultiKeySupport
 		cmd = self._command_map[key]
 		if cmd == urwid.ACTIVATE:
 			self.focus_btn_select()
+		elif self.key_handler and not self.key_handler(self._command_map, size, key):
+			pass
 		else:
 			return key
 		return None
@@ -562,16 +575,22 @@ class PathEdit(urwid.WidgetWrap):
 		urwid_multi_key_support.HelpItem(urwid_dialog.PREV_SELECTABLE, 'focus previous'),
 	])
 
-	def __init__(self, app: App, label: str, start_path: str) -> None:
+	def __init__(self,
+		app: App,
+		label: str,
+		start_path: str,
+		key_handler: typing.Optional[typing.Callable[[urwid_multi_key_support.SubCommandMap, URWID_TYPE_SIZE, URWID_TYPE_KEY], typing.Optional[URWID_TYPE_KEY]]] = None,
+	) -> None:
 		self.app = app
 		self.edit = ExtendedEdit(label, start_path)
 		self.has_opened_directory_chooser = False
+		self.key_handler = key_handler
 		super().__init__(self.edit)
 
 	def on_browse(self) -> None:
 		self.has_opened_directory_chooser = True
 		self.last_view = self.app.save_view()
-		self.app.open_view(DirectoryChooser(self.app, self.on_select, self.on_cancel, start_path=self.get_path()))
+		self.app.open_view(DirectoryChooser(self.app, self.on_select, self.on_cancel, start_path=self.get_path(), key_handler=self.key_handler))
 
 	def on_select(self, path: str) -> None:
 		self.has_opened_directory_chooser = False
