@@ -2,7 +2,7 @@
 
 import enum
 
-from udsync import main
+import udsync.main
 from udsync import config
 
 # the setup of other tests clear this dict so I need to save the values before any tests run
